==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/admin/story-link.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");
include("../include/header.inc.php");

$VAR["Heading"] = _STORY_EXT;
$VAR["Content"] = "
<FORM	ACTION=\"$CONF[G_URL]/admin/submit.php\" NAME=\"config\" METHOD=\"POST\">
<TABLE CELLPADDING=2 CELLSPACING=1 WIDTH=100% BORDER=1>
<tr><td>"._STORY_LINK_INDEX."</td><td>
<table border=0 cellpadding=0 cellspacing=0 width=\"100%\"><tr>
<td><select name=\"IndexKills[]\" size=5 multiple>";

# list index names
$sql	= "SELECT * FROM T_IndexNames";
$result	= SqlQuery($sql);
$nrows	= mysql_num_rows($result);
for ($i=0;$i<$nrows;$i++) {
	$A	= mysql_fetch_array($result);
	$VAR["Content"] .= sprintf("<option>%s</option>\n",$A["Name"]);
}

$VAR["Content"] .= "</select></td>
<td><input type=submit name=\"action\" value=\"kill\">
<small>" . _STORY_LINK_INDEX_KILL ."
</small>
</td></tr></table>
</td></tr>
<TR>
<TD>"._STORY_LINK_INDEX_ADD."</TD>
<TD>
<INPUT TYPE=\"TEXT\" NAME=\"IndexName\" SIZE=" . KWL_FormSize(15) . " MAXLENGTH=48>
</TD>
</TR>
<TR>
	<TD COLSPAN=2>
	<INPUT TYPE=HIDDEN NAME=\"what\" VALUE=\"story-link\">
	<INPUT TYPE=SUBMIT VALUE=\""._SAVE_CHANGE."\">
	</TD>
</TR></TABLE>
</FORM>
";

KWL_DrawMain($VAR);
include("../include/footer.inc.php");
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/admin/story-link.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");
include("../include/header.inc.php");

$VAR["Heading"] = _STORY_EXT;
$VAR["Content"] = "
<form	action=\"$CONF[G_URL]/admin/submit.php\" name=\"config\" method=\"post\">
<table cellpadding=0 cellspacing=5 width=100% border=0>
<tr><td>"._STORY_LINK_INDEX."</td><td>
<table border=0 cellpadding=0 cellspacing=0 width=\"100%\"><tr>
<td><select name=\"IndexKills[]\" size=5 multiple>";

# list index names
$sql	= "SELECT * FROM T_IndexNames";
$result	= SqlQuery($sql);
$nrows	= mysql_num_rows($result);
for ($i=0;$i<$nrows;$i++) {
	$A	= mysql_fetch_array($result);
	$VAR["Content"] .= sprintf("<option>%s</option>\n",$A["Name"]);
}

$VAR["Content"] .= "</select></td>
<td><input type=submit name=\"action\" value=\"kill\">
" . _STORY_LINK_INDEX_KILL ."
</td></tr></table>
</td></tr>
<tr>
<td>"._STORY_LINK_INDEX_ADD."</td>
<td>
<input type=\"text\" name=\"IndexName\" size=" . KWL_FormSize(15) . " maxlength=\"48\">
</td>
</tr>
<tr>
	<td colspan=\"2\">
	<input type=hidden name=\"what\" VALUE=\"story-link\">
	<input type=submit value=\""._SAVE_CHANGE."\">
	</td>
</tr></table>
</form>
";

KWL_DrawMain($VAR);
include("../include/footer.inc.php");
?>
